##############################################
# R script for lab exercise on preferential
# trade agreements, and example for the
# analysis of undirected networks' dynamics.
# version of 8 February 2017
# written by Christian Steglich
##############################################
# Thanks to Mark Pickup, Mark Manger, and
# Tom Snijders for making their compiled
# data sets available!
##############################################

# Load vocabulary for analysing network dynamics:
library(RSiena)

# Set directory to where the data are:
setwd('<put here path to folder where data are located>')

# Check:
getwd()
list.files()

# Read PTA data [waves 5,6,7 of total data set]:
net98 <- as.matrix(read.table("CoevPTA1998.dat"))
net99 <- as.matrix(read.table("CoevPTA1999.dat"))
net00 <- as.matrix(read.table("CoevPTA2000.dat"))

# Read country-level variables:
democ  <- as.matrix(read.table("Democ94-04.dat"))[,5:7]
invGDP <- as.matrix(read.table("invGDP94-04.dat"))[,5:7]

# Read constant dyad-level variable:
dist <- as.matrix(read.table("Coevdist.dat"))

# Read changing dyad-level variable:
Trade98  <- as.matrix(read.table("Cvtrade1998.dat"))
Trade99  <- as.matrix(read.table("Cvtrade1999.dat"))

# Prepare data for RSiena:
# 1) create dependent network variable:
PTAs     <- sienaDependent(array(c(net98,net99,net00),dim=c(145,145,3)))
# 2) create actor-level covariates:
binDemocracy <- varCovar(1*(democ>median(democ))) 
GDP_inv  <- varCovar(invGDP)
# 3) create dyad-level covariates:
Distance <- coDyadCovar(dist)
Trade    <- varDyadCovar(array(c(Trade98,Trade99),dim=c(145,145,2)))

# Define data object for RSiena analysis:
PTAdata <- sienaDataCreate(PTAs,binDemocracy,GDP_inv,
	Distance,Trade)

# Generate report file about data input:
print01Report(PTAdata,modelname='pta-example-init' )
# (is created in current working directory).

# Create effects structure for RSiena model specification:
PTAeff <- getEffects(PTAdata)

# Define non-directed model of type "unilateral initiative, reciprocal
# confirmation".
PTAoptions <- sienaAlgorithmCreate(projname="pta-example-results",modelType=3)

# Specify a model by selecting effects into it:
PTAeff <- setEffect(PTAeff,transTriads)
PTAeff <- includeEffects(PTAeff,X,interaction1="Distance")
PTAeff <- includeEffects(PTAeff,X,interaction1="Trade")
PTAeff <- includeEffects(PTAeff,altX,sameX,interaction1="binDemocracy")
PTAeff <- includeInteraction(PTAeff, altX, sameX, interaction1=c("binDemocracy","binDemocracy"))
PTAeff <- includeEffects(PTAeff,altX,interaction1="GDP_inv")
PTAeff <- includeInteraction(PTAeff,X,altX,interaction1=c("Trade","GDP_inv"))

# If desired, check the current model specification:
PTAeff

# Estimate the model and store results in new object:
PTAres <- siena07(PTAoptions,data=PTAdata,effects=PTAeff)

# Take a look at the results:
PTAres

# One could now e.g. check to what degree the omission
# of triad-level effects would bias the other estimates:
PTAeff <- setEffect(PTAeff,transTriads,include=FALSE)
# ... & re-run the 'siena07' command above.
